@@ -8,6 +8,7 @@ import re
 from config_models.models import ConfigurationModel, ConfigurationModelManager
 from django.db import models
 from edx_django_utils.cache.utils import TieredCache, get_cache_key
+from fernet_fields import EncryptedCharField
 
 from event_routing_backends.helpers import backend_cache_ttl
 from event_routing_backends.utils.fields import EncryptedJSONField
@@ -87,10 +88,7 @@ class RouterConfiguration(ConfigurationModel):
                 'data.key': 'value'
             },
             'host_configurations': {
-                'url': 'http://test1.com',
                 'headers': {},
-                'auth_scheme': 'Bearer',
-                'auth_key': 'test_key'
             },
             'override_args': {
                 'new_key': 'new_value'
@@ -102,7 +100,6 @@ class RouterConfiguration(ConfigurationModel):
                 'data.key': 'value'
             },
             'host_configurations': {
-                'url': 'http://test1.com',
             },
         },
     ]
@@ -117,13 +114,20 @@ class RouterConfiguration(ConfigurationModel):
 
     """
 
+    AUTH_BASIC = 'Basic'
+    AUTH_BEARER = 'Bearer'
+    AUTH_CHOICES = ((AUTH_BASIC, 'Basic'), (AUTH_BEARER, 'Bearer'),)
+    CALIPER_BACKEND = 'Caliper'
+    XAPI_BACKEND = 'xAPI'
+    BACKEND_CHOICES = ((CALIPER_BACKEND, 'Caliper'), (XAPI_BACKEND, 'xAPI'),)
     KEY_FIELDS = ('route_url',)
     backend_name = models.CharField(
+        choices=BACKEND_CHOICES,
         max_length=50,
-        verbose_name='Backend name',
         null=False,
         blank=False,
         db_index=True,
+        default=XAPI_BACKEND,
         help_text=(
             'Name of the tracking backend on which this router should be applied.'
             '<br/>'
@@ -143,7 +147,33 @@ class RouterConfiguration(ConfigurationModel):
         )
     )
 
-    configurations = EncryptedJSONField()
+    auth_scheme = models.CharField(
+        choices=AUTH_CHOICES,
+        verbose_name='Auth Scheme',
+        max_length=6,
+        default=None,
+        blank=True,
+        null=True
+    )
+    auth_key = EncryptedCharField(
+        verbose_name='Auth Key',
+        max_length=256,
+        blank=True,
+        null=True
+    )
+    username = EncryptedCharField(
+        verbose_name='Username',
+        max_length=256,
+        blank=True,
+        null=True
+    )
+    password = EncryptedCharField(
+        verbose_name='Password',
+        max_length=256,
+        blank=True,
+        null=True
+    )
+    configurations = EncryptedJSONField(blank=True, default=None)
     objects = RouterConfigurationManager()
 
     class Meta:
@@ -181,7 +211,7 @@ class RouterConfiguration(ConfigurationModel):
         router_configs = cls.objects.get_routers(backend_name)
         return router_configs if len(router_configs) > 0 else None
 
-    def get_allowed_hosts(self, original_event):
+    def get_allowed_host(self, original_event):
         """
         Return list of hosts to which the `transformed_event` is allowed to be sent.
 
@@ -222,16 +252,17 @@ class RouterConfiguration(ConfigurationModel):
             original_event    (dict):       original event dict
 
         Returns
-            list<dict>
+            dict
         """
-        allowed_hosts = []
-        for host_config in self.configurations:
-            is_allowed = self._match_event_for_host(original_event, host_config)
+        if not self.configurations:
+            return {'host_configurations': {}}
 
-            if is_allowed:
-                allowed_hosts.append(host_config)
+        is_allowed = self._match_event_for_host(original_event, self.configurations)
 
-        return allowed_hosts
+        if is_allowed:
+            return self.configurations
+
+        return None
 
     def _match_event_for_host(self, original_event, host_config):
         """
